function [time_P, angle_P] = cal_time_angle_P(model, dist, depth, slowness)
% Calculating the P wave traveltime and the angle of ray vector of given 
% grid. 
% Use the traveltime of (dist, depth) = (0, disc_depth) as time zero. Basic
% equations for plane wave.



    % model parameters
    moho_depth   = model.moho_depth;
    moho_dipping = model.moho_dipping;
    disc_depth   = model.disc_depth;
    disc_dipping = model.disc_dipping;

    Vp_crust  = model.Vp_crust;
%    Vs_crust  = model.Vs_crust ; 
    Vp_mantle = model.Vp_mantle;
%    Vs_mantle = model.Vs_mantle;
    Vp_bottom = model.Vp_bottom;
%    Vs_bottom = model.Vs_bottom;
    
    
    theta_P = asind(slowness*Vp_bottom);    % incidence of P wave in the bottom layer
    
       
    % angles for calculation
    alpha_disc_DP = asind(sind(disc_dipping - theta_P)*Vp_mantle/Vp_bottom);
    alpha_moho_DP = asind(sind(moho_dipping - disc_dipping + alpha_disc_DP)*Vp_crust/Vp_mantle);
 
    tmp_depth_moho = (dist*tand(moho_dipping) + moho_depth);
    if ( depth < tmp_depth_moho )   % inside the first layer
        x_moho_DP = ( dist - (moho_depth - depth) * tand(moho_dipping - alpha_moho_DP) )/( 1 + tand(moho_dipping)*tand(moho_dipping - alpha_moho_DP));    
        d_moho_DP = x_moho_DP * tand(moho_dipping) + moho_depth;
        
        x_disc_DP = ( x_moho_DP - (disc_depth - d_moho_DP) * tand(disc_dipping-alpha_disc_DP))/(1 + tand(disc_dipping)*tand(disc_dipping - alpha_disc_DP));    
        d_disc_DP = x_disc_DP * tand(disc_dipping) + disc_depth;
        
        time_p1_DP = -(x_disc_DP * sind(disc_dipping - theta_P))/(Vp_bottom * cosd(disc_dipping));    
        time_p2_DP = sqrt((x_moho_DP - x_disc_DP).^2 + (d_moho_DP - d_disc_DP).^2)/Vp_mantle;    
        time_p3_DP = sqrt((dist - x_moho_DP).^2 + (depth - d_moho_DP).^2)/Vp_crust;
        
        time_P  = time_p1_DP + time_p2_DP + time_p3_DP;
        angle_P = moho_dipping - alpha_moho_DP;
        
        return;
        
    else
        tmp_depth_disc = (dist*tand(disc_dipping) + disc_depth);
        if ( depth < tmp_depth_disc )   % inside the second layer
            x_disc_DP = ( dist - (disc_depth - depth) * tand(disc_dipping-alpha_disc_DP))/(1 + tand(disc_dipping)*tand(disc_dipping - alpha_disc_DP));    
            d_disc_DP = x_disc_DP * tand(disc_dipping) + disc_depth;
            
            time_p1_DP = -(x_disc_DP * sind(disc_dipping - theta_P))/(Vp_bottom * cosd(disc_dipping));    
            time_p2_DP = sqrt((dist - x_disc_DP).^2 + (depth - d_disc_DP).^2)/Vp_mantle;    
            
            time_P  = time_p1_DP + time_p2_DP;
            angle_P = disc_dipping - alpha_disc_DP;
            
            return;
            
        else                           % inside the third (bottom) layer
            
            time_p1_DP = -(depth - disc_depth - dist*tand(theta_P))*cosd(theta_P)/Vp_bottom;
            
            time_P = time_p1_DP;
            angle_P = theta_P;
            
            return;
            
        end
    end
    
end