clear all
close all

%% Model Setting
% interface 1
model.moho_depth   = 40.0;  % depth of moho (interface 1) in km
model.moho_dipping = 10.0;  % dipping angle of moho in degrees
% interface 2
model.disc_depth   = 60.0;  % depth of discontinuity (interface 2) in km
model.disc_dipping = 20.0;  % dipping angle of discontinuity in degrees
% velocity structures
model.Vp_crust     = 6.0;   % Vp of first layer in km/s
model.Vs_crust     = 3.42;  % Vs of first layer in km/s
model.Vp_mantle    = 8.0;   % Vp of second layer
model.Vs_mantle    = 4.45;  % Vs of second layer
model.Vp_bottom    = 10.0;  % Vp of third (bottom) layer
model.Vs_bottom    = 5.5;   % Vs of third (bottom) layer


%% Initialization 

% stations
station_spacing = 5;
x_station = 10:station_spacing:290;

% parameters of migration area
dist_vec  = 0:1:300;
depth_vec = 0:1:200;

% width of gauss wavelet
width_gauss = 0.1;

% model parameters
moho_depth   = model.moho_depth;
moho_dipping = model.moho_dipping;
disc_depth   = model.disc_depth;
disc_dipping = model.disc_dipping;

Vp_crust  = model.Vp_crust;
Vs_crust  = model.Vs_crust ; 
Vp_mantle = model.Vp_mantle;
Vs_mantle = model.Vs_mantle;
Vp_bottom = model.Vp_bottom;
Vs_bottom = model.Vs_bottom;

%% plot model setting
max_dist  = x_station(length(x_station)) + moho_depth;
max_depth = x_station(length(x_station)) * tand(disc_dipping) + 2*disc_depth;
clf,figure(1)
% moho(interface) 
plot([0, max_dist],[moho_depth, max_dist*tand(moho_dipping) + moho_depth],'g')
hold on
% reference line at moho depth
plot([0, moho_depth],[moho_depth, moho_depth],'--k')
% discontinuity
plot([0, max_dist],[disc_depth, max_dist*tand(disc_dipping) + disc_depth],'g')
% reference line at discontinuity depth
plot([0, moho_depth],[disc_depth, disc_depth],'--k')
% surface
plot([0, max_dist],[0, 0],'k')
% stations
scatter(x_station,zeros(length(x_station),1)-1,30,'k','filled','v')


xlim([0 max_dist])
ylim([-5 max_depth])
set(gca,'Ydir','reverse')
width_height_ratio = max_dist/max_depth;
set(gcf,'Units','centimeters','InnerPosition',[5 5 15*[width_height_ratio 1]])
xlabel('distance(km)')
ylabel('depth(km)')

text(0.4*max_dist, 0.4*max_dist*tand(moho_dipping) + moho_depth - 5, '\downarrow moho')
text(0.4*max_dist, 0.4*max_dist*tand(disc_dipping) + disc_depth - 5, '\downarrow discontinuity')

textstr = {'first layer' ;['Vp=' num2str(Vp_crust) 'km/s'] ;['Vs=' num2str(Vs_crust) 'km/s']};
text(max_dist-60, 20, textstr)
textstr = {'second layer';['Vp=' num2str(Vp_mantle) 'km/s'];['Vs=' num2str(Vs_mantle) 'km/s']};
text(max_dist-60, moho_depth + max_dist * tand(moho_dipping) + 20, textstr)
textstr = {'bottom layer';['Vp=' num2str(Vp_bottom) 'km/s'];['Vs=' num2str(Vs_bottom) 'km/s']};
text(max_dist-60, disc_depth + max_dist * tand(disc_dipping) + 20, textstr)



%print('model_setting_three_layers.jpeg',figure(1),'-djpeg','-r900')
